@@ -55,6 +55,12 @@ from python_kemptech_api.utils import (
     HTTPBasicAuthUTF8
 )
 
+# For compatablilty with both 2.7 and 3.4
+try:
+    import urllib.parse as urlencoder
+except ImportError:
+    import urllib as urlencoder
+
 log = logging.getLogger(__name__)
 
 
@@ -405,6 +411,12 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
                 raise DownloadUserCertFailed(self.ip_address)
         return file_name
 
+    def restore_cert(self, password, file, restore_type="all"):
+        params = {"password": password, "type": restore_type}
+        response = self._post('/restorecert', file=file,
+                              parameters=params)
+        return send_response(response)
+
     def shutdown(self):
         response = self._get('/shutdown')
         return is_successful(response)
@@ -1341,6 +1353,32 @@ class LoadMaster(BaseKempAppliance):
             cert = IntermediateCertificate(self.access_info, certificate)
         return cert
 
+    def backup_cert(self, password, file_name=None, location='backups'):
+        """
+        Create certificate backup with the provided password and optional
+        filename
+        """
+
+        if not os.path.exists(location):
+            os.makedirs(location)
+
+        if file_name is None:
+            file_name = os.path.join(location, "{}_{}.backup".format(
+                self.ip_address, time.strftime("%Y-%m-%d_%H:%M:%S")))
+
+        with open(file_name, 'wb') as file:
+            cmd = self._get_curl_command_list(
+                'backupcert?{}'.format(
+                    urlencoder.urlencode({"password": password})
+                )
+            )
+            subprocess.call(cmd, stdout=file)
+            file.seek(0, 2)
+            if file.tell() == 0:
+                raise BackupFailed(self.ip_address)
+
+        return file_name
+
     def create_virtual_service(self, ip, port=80, protocol="tcp"):
         return VirtualService(self.access_info, ip, port, protocol)
 
